define(
//begin v1.x content
{
	"dateFormatItem-yMMMM": "LLLL y",
	"field-thu-narrow-relative+0": "tento št.",
	"field-thu-narrow-relative+1": "budúci št.",
	"field-sun-narrow-relative+0": "túto ne.",
	"field-sun-narrow-relative+1": "budúcu ne.",
	"months-format-wide": [
		"januára",
		"februára",
		"marca",
		"apríla",
		"mája",
		"júna",
		"júla",
		"augusta",
		"septembra",
		"októbra",
		"novembra",
		"decembra"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-fri-narrow-relative+0": "tento pi.",
	"field-fri-narrow-relative+1": "budúci pi.",
	"eraNarrow": [
		"pred Kr.",
		"po Kr."
	],
	"dateFormatItem-Hmv": "H:mm v",
	"dateFormatItem-hmsv": "h:mm:ss a v",
	"dateFormatItem-yMMMd": "d. M. y",
	"dayPeriods-format-abbr-night1": "v noci",
	"dayPeriods-format-narrow-evening1": "več.",
	"days-standAlone-narrow": [
		"n",
		"p",
		"u",
		"s",
		"š",
		"p",
		"s"
	],
	"days-standAlone-wide": [
		"nedeľa",
		"pondelok",
		"utorok",
		"streda",
		"štvrtok",
		"piatok",
		"sobota"
	],
	"dayPeriods-format-abbr-afternoon1": "popol.",
	"dayPeriods-format-wide-evening1": "večer",
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "minulú st.",
	"dayPeriods-standAlone-wide-evening1": "večer",
	"days-format-wide": [
		"nedeľa",
		"pondelok",
		"utorok",
		"streda",
		"štvrtok",
		"piatok",
		"sobota"
	],
	"field-month-short-relative+0": "tento mes.",
	"field-month-short-relative+1": "budúci mes.",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-standAlone-narrow-evening1": "več.",
	"dayPeriods-standAlone-abbr-afternoon1": "popol.",
	"field-thu-relative+0": "tento štvrtok",
	"dayPeriods-standAlone-abbr-night1": "noc",
	"field-thu-relative+1": "budúci štvrtok",
	"dayPeriods-format-wide-am": "AM",
	"field-fri-relative+0": "tento piatok",
	"field-fri-relative+1": "budúci piatok",
	"dateFormatItem-yMd": "d. M. y",
	"field-thu-narrow-relative+-1": "minulý št.",
	"field-quarter-relative+0": "tento štvrťrok",
	"field-quarter-relative+1": "budúci štvrťrok",
	"field-sun-short-relative+0": "túto ned.",
	"timeFormat-short": "H:mm",
	"field-sun-short-relative+1": "budúcu ned.",
	"dateFormatItem-hms": "h:mm:ss a",
	"dayPeriods-format-narrow-afternoon1": "pop.",
	"dateFormatItem-Md": "d. M.",
	"dateFormatItem-Hmsv": "H:mm:ss v",
	"dateFormatItem-hmv": "h:mm a v",
	"field-week-narrow": "týž.",
	"field-hour-relative+0": "v tejto hodine",
	"field-day-relative+-1": "včera",
	"field-day-relative+-2": "predvčerom",
	"field-mon-narrow-relative+-1": "minulý po.",
	"field-minute-narrow": "min",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"field-thu-short-relative+0": "tento št.",
	"field-mon-relative+0": "tento pondelok",
	"field-thu-short-relative+1": "budúci št.",
	"field-mon-relative+1": "budúci pondelok",
	"field-day-narrow-relative+0": "dnes",
	"field-era-short": "letop.",
	"field-day-narrow-relative+1": "zajtra",
	"field-sat-narrow-relative+0": "túto so.",
	"field-day-narrow-relative+2": "pozajtra",
	"timeFormat-long": "H:mm:ss z",
	"field-sat-narrow-relative+1": "budúcu so.",
	"field-wed-narrow-relative+0": "túto st.",
	"field-wed-narrow-relative+1": "budúcu st.",
	"field-month": "mesiac",
	"months-standAlone-wide": [
		"január",
		"február",
		"marec",
		"apríl",
		"máj",
		"jún",
		"júl",
		"august",
		"september",
		"október",
		"november",
		"december"
	],
	"field-weekday-narrow": "deň týž.",
	"dayPeriods-standAlone-narrow-afternoon1": "pop.",
	"field-year-relative+0": "tento rok",
	"field-year-relative+1": "budúci rok",
	"dayPeriods-format-abbr-evening1": "večer",
	"dayPeriods-format-abbr-noon": "napol.",
	"dayPeriods-format-narrow-midnight": "o poln.",
	"dayPeriods-format-wide-midnight": "o polnoci",
	"field-tue-relative+0": "tento utorok",
	"dateFormatItem-GyMMMMd": "d. M. y G",
	"field-tue-relative+1": "budúci utorok",
	"dayPeriods-standAlone-abbr-evening1": "večer",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-standAlone-wide-midnight": "polnoc",
	"field-year-narrow": "r.",
	"dateFormatItem-mmss": "mm:ss",
	"dayPeriods-standAlone-abbr-noon": "pol.",
	"field-tue-short-relative+0": "tento utor.",
	"dayPeriods-standAlone-narrow-midnight": "poln.",
	"field-tue-short-relative+1": "budúci utor.",
	"field-tue-narrow-relative+0": "tento ut.",
	"field-tue-narrow-relative+1": "budúci ut.",
	"dateTimeFormat-full": "{1}, {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "H",
	"field-wed-relative+0": "túto stredu",
	"field-wed-relative+1": "budúcu stredu",
	"dateFormatItem-M": "L.",
	"field-wed-short-relative+0": "túto str.",
	"field-fri-short-relative+0": "tento pi.",
	"field-wed-short-relative+1": "budúcu str.",
	"field-fri-short-relative+1": "budúci pi.",
	"field-weekOfMonth-short": "týž. mes.",
	"field-quarter-short-relative+-1": "minulý štvrťr.",
	"field-year-short-relative+-1": "minulý rok",
	"dateFormatItem-Bhm": "h:mm B",
	"dayPeriods-format-wide-night1": "v noci",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-quarter-narrow-relative+-1": "minulý štvrťr.",
	"dateFormatItem-d": "d.",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"1. štvrťrok",
		"2. štvrťrok",
		"3. štvrťrok",
		"4. štvrťrok"
	],
	"field-weekOfMonth-narrow": "týž. mes.",
	"dateFormatItem-y": "y",
	"field-minute-relative+0": "v tejto minúte",
	"field-year-short-relative+0": "tento rok",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "budúci rok",
	"field-weekday": "deň týždňa",
	"dayPeriods-format-narrow-pm": "PM",
	"field-tue-narrow-relative+-1": "minulý ut.",
	"dateFormatItem-yMEd": "E d. M. y",
	"dayPeriods-standAlone-wide-night1": "noc",
	"field-year-narrow-relative+-1": "minulý rok",
	"field-sat-relative+-1": "minulú sobotu",
	"dayPeriods-format-abbr-midnight": "o poln.",
	"dayPeriods-format-narrow-morning1": "ráno",
	"dayPeriods-format-narrow-morning2": "dop.",
	"dayPeriods-format-wide-morning1": "ráno",
	"dayPeriods-format-wide-morning2": "dopoludnia",
	"dayPeriods-standAlone-abbr-midnight": "poln.",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"dayPeriods-standAlone-wide-morning1": "ráno",
	"field-mon-narrow-relative+0": "tento po.",
	"dayPeriods-standAlone-wide-morning2": "dopoludnie",
	"field-mon-narrow-relative+1": "budúci po.",
	"field-second": "sekunda",
	"dateFormatItem-yMMMEd": "E d. M. y",
	"field-year-relative+-1": "minulý rok",
	"field-weekdayOfMonth-short": "d.  týž. v mes.",
	"dateFormat-short": "d. M. y",
	"eraNames": [
		"pred Kristom",
		"po Kristovi"
	],
	"field-second-short": "s",
	"field-thu-short-relative+-1": "minulý št.",
	"field-zone": "časové pásmo",
	"field-dayperiod-narrow": "AM/PM",
	"field-sun-short-relative+-1": "minulú ned.",
	"dayPeriods-standAlone-narrow-morning1": "ráno",
	"dayPeriods-standAlone-narrow-morning2": "dop.",
	"eraAbbr": [
		"pred Kr.",
		"po Kr."
	],
	"field-week-short": "týž.",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "dnes",
	"field-day-relative+1": "zajtra",
	"field-day-relative+2": "pozajtra",
	"field-day-short-relative+0": "dnes",
	"field-dayOfYear-short": "deň r.",
	"field-day-short-relative+1": "zajtra",
	"dateFormat-long": "d. MMMM y",
	"field-day-short-relative+2": "pozajtra",
	"field-sun-narrow-relative+-1": "minulú ne.",
	"dayPeriods-format-wide-noon": "napoludnie",
	"field-second-relative+0": "teraz",
	"field-quarter-relative+-1": "minulý štvrťrok",
	"dayPeriods-format-narrow-night1": "v n.",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dayPeriods-standAlone-wide-noon": "poludnie",
	"dayPeriods-standAlone-narrow-night1": "noc",
	"field-week-relative+-1": "minulý týždeň",
	"dayPeriods-format-abbr-morning1": "ráno",
	"field-month-relative+-1": "minulý mesiac",
	"dayPeriods-format-abbr-morning2": "dopol.",
	"months-format-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"field-year": "rok",
	"field-era": "letopočet",
	"dayPeriods-standAlone-abbr-morning1": "ráno",
	"dayPeriods-standAlone-abbr-morning2": "dopol.",
	"days-standAlone-short": [
		"ne",
		"po",
		"ut",
		"st",
		"št",
		"pi",
		"so"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-day-short-relative+-1": "včera",
	"field-day-short-relative+-2": "predvčerom",
	"dateFormatItem-GyMMM": "LLLL y G",
	"timeFormat-full": "H:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "hodina",
	"field-dayOfYear-narrow": "deň r.",
	"field-quarter": "štvrťrok",
	"field-day": "deň",
	"field-mon-relative+-1": "minulý pondelok",
	"field-dayOfYear": "deň roka",
	"dateFormat-medium": "d. M. y",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-yMMM": "M/y",
	"dateFormatItem-GyMMMd": "d. M. y G",
	"dateFormatItem-MEd": "E d. M.",
	"field-tue-short-relative+-1": "minulý utor.",
	"field-year-short": "r.",
	"field-month-short": "mes.",
	"dateFormatItem-MMMEd": "E d. M.",
	"dayPeriods-format-wide-afternoon1": "popoludní",
	"dateFormatItem-MMMd": "d. M.",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"máj",
		"jún",
		"júl",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "túto sobotu",
	"field-sat-relative+1": "budúcu sobotu",
	"dayPeriods-format-wide-pm": "PM",
	"field-zone-short": "pásmo",
	"days-standAlone-abbr": [
		"ne",
		"po",
		"ut",
		"st",
		"št",
		"pi",
		"so"
	],
	"field-week-short-relative+0": "tento týž.",
	"dateFormatItem-yMMMMd": "d. MMMM y",
	"field-week-short-relative+1": "budúci týž.",
	"dayPeriods-standAlone-wide-afternoon1": "popoludnie",
	"field-fri-short-relative+-1": "minulý pi.",
	"field-month-narrow": "mes.",
	"dayPeriods-format-narrow-am": "AM",
	"days-format-abbr": [
		"ne",
		"po",
		"ut",
		"st",
		"št",
		"pi",
		"so"
	],
	"field-weekday-short": "deň týž.",
	"field-day-narrow-relative+-1": "včera",
	"field-day-narrow-relative+-2": "predvčerom",
	"field-quarter-short": "Q",
	"days-format-short": [
		"ne",
		"po",
		"ut",
		"st",
		"št",
		"pi",
		"so"
	],
	"months-standAlone-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"days-format-narrow": [
		"n",
		"p",
		"u",
		"s",
		"š",
		"p",
		"s"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "Q",
	"field-mon-short-relative+0": "tento pond.",
	"field-mon-short-relative+1": "budúci pond.",
	"field-dayperiod-short": "AM/PM",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-thu-relative+-1": "minulý štvrtok",
	"field-fri-narrow-relative+-1": "minulý pi.",
	"field-mon-short-relative+-1": "minulý pond.",
	"timeFormat-medium": "H:mm:ss",
	"field-quarter-short-relative+0": "tento štvrťr.",
	"field-quarter-short-relative+1": "budúci štvrťr.",
	"dateFormatItem-Ed": "E d.",
	"field-wed-relative+-1": "minulú stredu",
	"field-weekOfMonth": "týždeň mesiaca",
	"field-weekdayOfMonth-narrow": "d.  týž. v mes.",
	"dayPeriods-standAlone-wide-am": "AM",
	"dateFormatItem-yQQQ": "QQQ y",
	"field-fri-relative+-1": "minulý piatok",
	"field-minute": "minúta",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"quarters-format-wide": [
		"1. štvrťrok",
		"2. štvrťrok",
		"3. štvrťrok",
		"4. štvrťrok"
	],
	"field-day-short": "d.",
	"field-dayperiod": "AM/PM",
	"field-hour-short": "h",
	"months-standAlone-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"máj",
		"jún",
		"júl",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"field-second-narrow": "s",
	"field-month-relative+0": "tento mesiac",
	"field-month-relative+1": "budúci mesiac",
	"dateFormat-full": "EEEE d. MMMM y",
	"field-era-narrow": "letop.",
	"field-sat-short-relative+-1": "minulú so.",
	"dayPeriods-format-narrow-noon": "nap.",
	"field-week-short-relative+-1": "minulý týž.",
	"dateTimeFormat-long": "{1}, {0}",
	"dateFormatItem-yM": "M/y",
	"field-sun-relative+-1": "minulú nedeľu",
	"field-wed-short-relative+-1": "minulú str.",
	"field-weekdayOfMonth": "deň týždňa v mesiaci",
	"field-quarter-narrow-relative+0": "tento štvrťr.",
	"dateFormatItem-GyMMMEd": "E d. M. y G",
	"field-quarter-narrow-relative+1": "budúci štvrťr.",
	"field-sat-short-relative+0": "túto so.",
	"field-hour-narrow": "h",
	"field-sat-short-relative+1": "budúcu so.",
	"field-year-narrow-relative+0": "tento rok",
	"field-year-narrow-relative+1": "budúci rok",
	"dateFormatItem-Gy": "y G",
	"field-zone-narrow": "pásmo",
	"dayPeriods-standAlone-narrow-noon": "pol.",
	"field-tue-relative+-1": "minulý utorok",
	"field-minute-short": "min",
	"dateFormatItem-yw": "w. 'týždeň' 'roka' Y",
	"dateFormatItem-Hm": "H:mm",
	"field-week-relative+0": "tento týždeň",
	"field-week-relative+1": "budúci týždeň",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "túto nedeľu",
	"field-sun-relative+1": "budúcu nedeľu",
	"field-sat-narrow-relative+-1": "minulú so.",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dateFormatItem-MMMMW": "W. 'týždeň' MMMM",
	"field-month-short-relative+-1": "minulý mes.",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-week": "týždeň",
	"field-day-narrow": "d."
}
//end v1.x content
);